==> haskell-path-io-1.4.0-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-io
version: 1.4.0
id: path-io-1.4.0-5wrZJMXlKZM92l3b0iHoKt
key: path-io-1.4.0-5wrZJMXlKZM92l3b0iHoKt
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/path-io
synopsis: Interface to ‘directory’ package for users of ‘path’
description:
    Interface to ‘directory’ package for users of ‘path’.
category: System, Filesystem
abi: 0a7da1ada5f3568ef3be0f02033594e4
exposed: True
exposed-modules:
    Path.IO
import-dirs: /usr/lib/ghc-8.6.2/site-local/path-io-1.4.0
library-dirs: /usr/lib/ghc-8.6.2/site-local/path-io-1.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/path-io-1.4.0
hs-libraries: HSpath-io-1.4.0-5wrZJMXlKZM92l3b0iHoKt
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    dlist-0.8.0.5-HU8Aimky3DbFEV0DkwGifS
    exceptions-0.10.0-9c5BjQipUdiGeORB8copQH filepath-1.4.2.1
    path-0.6.1-IlnZZ1VsioE1N1LxhM0D5o
    temporary-1.3-u08bcW55BD8R66ioRtSEF time-1.8.0.2
    transformers-0.5.5.0 unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
haddock-interfaces: /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html: /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-io-1.4.0-21-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-io
version: 1.4.0
id: path-io-1.4.0-E9f0qEyOPLxHKCpgmeDiGg
key: path-io-1.4.0-E9f0qEyOPLxHKCpgmeDiGg
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/path-io
synopsis: Interface to ‘directory’ package for users of ‘path’
description:
    Interface to ‘directory’ package for users of ‘path’.
category: System, Filesystem
abi: 18c5bbe04d99a1812db95f6425893537
exposed: True
exposed-modules:
    Path.IO
import-dirs: /usr/lib/ghc-8.6.3/site-local/path-io-1.4.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/path-io-1.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/path-io-1.4.0
hs-libraries: HSpath-io-1.4.0-E9f0qEyOPLxHKCpgmeDiGg
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    dlist-0.8.0.5-HU8Aimky3DbFEV0DkwGifS
    exceptions-0.10.0-9c5BjQipUdiGeORB8copQH filepath-1.4.2.1
    path-0.6.1-1NoJOFao0mZ3S0m3xgCaDS
    temporary-1.3-u08bcW55BD8R66ioRtSEF time-1.8.0.2
    transformers-0.5.5.0 unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
haddock-interfaces: /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html: /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
